summaryrefslogtreecommitdiff
path: root/jstests/noPassthrough/auth_reject_mismatching_logical_times.js
diff options
context:
space:
mode:
authorDianna Hohensee <dianna.hohensee@10gen.com>2018-07-17 14:02:03 -0400
committerDianna Hohensee <dianna.hohensee@10gen.com>2018-07-25 16:10:42 -0400
commite7c2cbf88bc07549d634613049358214dbbaac4b (patch)
tree2c11bd73062d33364907764d4a144bdd72335d1e /jstests/noPassthrough/auth_reject_mismatching_logical_times.js
parenta3cde2d51b6ed790b0cbb1c6949e91f6e45b878e (diff)
downloadmongo-e7c2cbf88bc07549d634613049358214dbbaac4b.tar.gz
SERVER-36101 Replication should not depend on the presence of lastStableCheckpointTimestamp in status reports to identify recoverable rollback capable nodes
Diffstat (limited to 'jstests/noPassthrough/auth_reject_mismatching_logical_times.js')
-rw-r--r--jstests/noPassthrough/auth_reject_mismatching_logical_times.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/jstests/noPassthrough/auth_reject_mismatching_logical_times.js b/jstests/noPassthrough/auth_reject_mismatching_logical_times.js
index 0d2a368ad49..c6c3d70b295 100644
--- a/jstests/noPassthrough/auth_reject_mismatching_logical_times.js
+++ b/jstests/noPassthrough/auth_reject_mismatching_logical_times.js
@@ -46,8 +46,9 @@
const rst = new ReplSetTest({nodes: 2});
rst.startSet({keyFile: "jstests/libs/key1", shardsvr: ""});
- // TODO: Wait for stable checkpoint when SERVER-32672 is fixed.
- rst.initiateWithAnyNodeAsPrimary(null, "replSetInitiate", {doNotWaitForStableCheckpoint: true});
+ // TODO: Wait for stable recovery timestamp when SERVER-32672 is fixed.
+ rst.initiateWithAnyNodeAsPrimary(
+ null, "replSetInitiate", {doNotWaitForStableRecoveryTimestamp: true});
assert.commandWorked(st.s.adminCommand({addShard: rst.getURL()}));
const testDB = st.s.getDB("test");